Please see [https://docs.mlcommons.org/cm4mlops/scripts/TinyML-automation/flash-tinyml-binary](https://docs.mlcommons.org/cm4mlops/scripts/TinyML-automation/flash-tinyml-binary) for the documentation of this CM script.
